#!/usr/bin/python
#############################################################################
# Name:         check.py
# Purpose:      SSH Connectivity Adapter for Various Purposes
# Maintainer:   Torsten Kurbad
# Copyright:    (c) 2017 iwm-kmrc.de KMRC - Knowledge Media Research Center
# Licence:      GPL
#############################################################################
""" SSH Connectivity Adapter (check views)

"""
from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
from zope.publisher.browser import BrowserView

from sshadapter.interfaces import ISSHAdapter
from sshadapter.interfaces import ICheckSSHAdapter


class CheckSSHAdapterView(BrowserView):

    __used_for__ = ISSHAdapter

    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.__parent__ = context
        self.report = []

    def getConnInfo(self):
        """ Returns a dict with configuration information. """
        infoDict = {}
        infoDict['hostName'] = self.context.hostName
        infoDict['port'] = u'%d' % self.context.port
        infoDict['sshUser'] = self.context.sshUser
        infoDict['sshKeyConfigured'] = (self.context.sshUserKey is not None) and (self.context.sshUserKey != u'')
        return infoDict


    def checkConnection(self):
        """ Check connection and execute some commands on the appliance. """
        if self.request.get('runDefault', None):
            testadapter = ICheckSSHAdapter(self.context)
            self._addInfo(u'<strong>'
                          u'Test python connection to %s via SSH'
                          u'</strong>' % self.context.hostName)
            self.report = self.report + testadapter.testConnection()
            self._addInfo(u' ')
            self._addInfo(u'<strong>Tests done</strong>')
            self._addInfo(u' ')
    
            return self.report
        else:
            return u''

    def _addInfo(self, res):
        """ Add traceback info to the report list. """
        self.report.append(res)

    check = ViewPageTemplateFile('check.pt')
