#!/usr/bin/python
#############################################################################
# Name:         check.py
# Purpose:      SSH Connectivity Adapter for Various Purposes
# Maintainer:   Torsten Kurbad
# Copyright:    (c) 2017 iwm-kmrc.de KMRC - Knowledge Media Research Center
# Licence:      GPL
#############################################################################
""" SSH Connectivity Adapter (checks)

"""

import os.path

from paramiko import SSHException

from zope.interface import implements
from zope.security.proxy import removeSecurityProxy

from interfaces import ICheckSSHAdapter

class CheckSSHAdapter:
    """ SSH Connectivity Test Adapter. """

    implements(ICheckSSHAdapter)

    def __init__(self, context):
        self.context = context

    def testConnection(self):
        self.report = []
        adapter = removeSecurityProxy(self.context)
        self.report.append(u'... start check connection')

        self.report.append(u'... trying to connect:')
        self.report.append(u'... hostName              = %s' % adapter.hostName)
        self.report.append(u'... port              = %s' % adapter.port)
        self.report.append(u'... sshUser             = %s' % adapter.sshUser)
        self.report.append(u'... privateKey configured = %r' % ((adapter.sshUserKey is not None) and (adapter.sshUserKey != u'')))
        self.report.append(u'...')

        try:
            stdout, stderr = adapter.executeSSHCommand(u'uname -a')
            if (stderr is not None) and (stderr != u''):
                self.report.append(u"... <strong>Connection Succeeded but test command 'uname' failed to execute!</strong>")
                self.report.append(u'... Error message:')
                self.report.append(u'<pre>%s</pre>' % stderr)
            elif (stdout is not None) and (stdout != u''):
                self.report.append(u'... <strong>Connection OK!</strong>')
                self.report.append(u"... Result of 'uname -a':")
                self.report.append(u'<pre>%s</pre>' % stdout)
            else:
                self.report.append(u'... <strong>connection FAILED!</strong>')
                return self.report

            self.report.append(u'...')
            stdout, stderr = adapter.executeSSHCommand(u'pwd')
            if (stderr is not None) and (stderr != u''):
                self.report.append(u"... <strong>Connection Succeeded but test command 'pwd' failed to execute!</strong>")
                self.report.append(u'... Error message:')
                self.report.append(u'<pre>%s</pre>' % stderr)
            elif (stdout is not None) and (stdout != u''):
                self.report.append(u'... <strong>Connection OK!</strong>')
                self.report.append(u"... Result of 'pwd':")
                self.report.append(u'<pre>%s</pre>' % stdout)

        except SSHException as e:
            self.report.append(u'... <strong>SSH setup is wrong!</strong>')
            self.report.append(u'... Exception: %s' % e)

        except Exception as e:
            self.report.append(u'... <strong>Connection test failed!</strong>')
            self.report.append(u'... Exception: %s' % e)

        return self.report
