#!/usr/bin/python
#############################################################################
# Name:         interfaces.py
# Purpose:      SSH Connectivity Adapter for Various Purposes
# Maintainer:   Torsten Kurbad
# Copyright:    (c) 2013 iwm-kmrc.de KMRC - Knowledge Media Research Center
# Licence:      GPL
#############################################################################
""" SSH Connectivity Adapter (interfaces)

"""

from zope.interface import Interface
from zope.schema import Bool, Int, Password, Text, TextLine

from zope.i18nmessageid import MessageFactory
_ = MessageFactory('sshadapter')


class ISSHAdapter(Interface):
    """ Make SSH Connectivity Adapter Configuration Persistent in ZODB.
    
    """

    hostName = TextLine(
        title=_(u'Host name'),
        description=_(u'The remote hostname (or IP address) to connect to.'),
        required=True)

    port = Int(
        title=_(u'Port'),
        description=_(u'The remote port to connect to.'),
        default=22,
        required=True)

    sshUser = TextLine(
        title=_(u'User name'),
        description=_(u'User name to connect to remote host as.'),
        required=True)

    sshUserPassword = Password(
        title=_(u'Password (optional)'),
        description=_(u'Password of the remote user.'),
        required=False)

    sshUserKey = Text(
        title=_(u'SSH private key'),
        description=_(u'SSH RSA private key of the remote user.'),
        required=False)

    autoRegister = Bool(
        title=_(u'Autoregister'),
        description=_(u'Automatically register as V7000UAdapter utility.'),
        default=True,
        required=False)


class ICheckSSHAdapter(Interface):
    """ SSH Connectivity Test Adapter. """

    def testConnection():
        """ Return a list of connection results to display in TAL. """
